#ifndef _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_H_
#define _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_H_

#ifndef _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_CLASS_TYPE
#define _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_CLASS_TYPE

typedef Eo Efl_Ui_Spotlight_Fade_Manager;

#endif

#ifndef _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_TYPES
#define _EFL_UI_SPOTLIGHT_FADE_MANAGER_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
#define EFL_UI_SPOTLIGHT_FADE_MANAGER_CLASS efl_ui_spotlight_fade_manager_class_get()

EWAPI const Efl_Class *efl_ui_spotlight_fade_manager_class_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
